pub enum CarrierKeyType {
Direct {
key: [u8; 32],
},
Exchange {
public_key: PublicKey,
},
None,
}Variants
Direct
Use AES256 key
Exchange
Use key exchange to generate a shared key
None
Use own private key
Note If public key encryption is used, this will use your own private/public key for key exchange otherwise if its AES256, it will encrypt with that key itself