PrivateKey

Enum PrivateKey 

pub enum PrivateKey {
    Ed25519(SigningKey),
    Secp256k1(SigningKey),
    P256(SigningKey),
    P384(SigningKey),
    Aes256([u8; 32]),
}
Container of private keys

The following is supported

Variants



Ed25519(SigningKey)



Secp256k1(SigningKey)



P256(SigningKey)



P384(SigningKey)



Aes256([u8; 32])

Implementations

Source

impl PrivateKey

pub fn new() -> Self

Generates a new PrivateKey with randomly generated key

pub fn new_with(key_type: PrivateKeyType) -> Self

Generate a PrivateKey using PrivateKeyType

pub fn import(key_type: PrivateKeyType, key: Vec<u8>) -> Result<Self>

Import private key which is identified with PrivateKeyType

pub fn decode<B: AsRef<[u8]>>(bytes: B) -> Result<PrivateKey>

Imports a private key from bytes prefixed with a PrivateKeyType identifier

pub fn to_bytes(&self) -> Vec<u8>

Exports the keys out as bytes.

pub fn encode(&self) -> Vec<u8>

Exports the key out with an identifier

pub fn key_type(&self) -> PrivateKeyType

Provides the PrivateKeyType of the PrivateKey

pub fn public_key(&self) -> Result<PublicKey>

Provides the PublicKey of the PrivateKey Note: This will only work with asymmetric keys. Any symmetric keys will return Error::Unsupported

pub fn sign<B: AsRef<[u8]>>(&self, data: B) -> Result<Vec<u8>>

Sign the data provided using PrivateKey

pub fn sign_reader(&self, reader: &mut impl Read) -> Result<Vec<u8>>

Available on crate feature std only.

Sign the data from std::io::Read using PrivateKey

pub fn verify(&self, data: &[u8], signature: &[u8]) -> Result<()>

Verify the signature of the data provided using PrivateKey

pub fn verify_reader( &self, reader: &mut impl Read, signature: &[u8], ) -> Result<()>

Available on crate feature std only.

Verify the signature of the data from std::io::Read using PrivateKey

Source

impl PrivateKey

pub fn encrypt(&self, data: &[u8], pubkey: CarrierKeyType) -> Result<Vec<u8>>

Encrypt the data using PrivateKey. If PrivateKeyType::Aes256 is used, the pubkey will be ignored

pub fn encrypt_with_aad( &self, data: &[u8], pubkey: CarrierKeyType, aad: &[u8], ) -> Result<Vec<u8>>

pub fn decrypt(&self, data: &[u8], pubkey: CarrierKeyType) -> Result<Vec<u8>>

Decrypt the data using PrivateKey. If PrivateKeyType::Aes256 is used, the pubkey will be ignored

pub fn decrypt_with_aad( &self, data: &[u8], pubkey: CarrierKeyType, aad: &[u8], ) -> Result<Vec<u8>>

Source

impl PrivateKey

pub fn encrypt_stream( &self, reader: &mut impl Read, writer: &mut impl Write, pubkey: CarrierKeyType, ) -> Result<()>

Available on crate feature std only.

Encrypt the data stream from std::io::Read to std::io::Write using PrivateKey. If PrivateKeyType::Aes256 is used, the pubkey will be ignored

pub fn decrypt_stream( &self, reader: &mut impl Read, writer: &mut impl Write, pubkey: CarrierKeyType, ) -> Result<()>

Available on crate feature std only.

Decrypt the data stream from std::io::Read to std::io::Write using PrivateKey. If PrivateKeyType::Aes256 is used, the pubkey will be ignored